@@ -22,6 +22,7 @@
 #include <glibmm/ustring.h>
 #include <glibmm/enums.h>
 #include <glib-object.h>
+#include <vector>
 
 namespace Glib
 {
@@ -196,9 +197,28 @@ protected:
   const char* get_cstring() const; // never returns nullptr
 };
 
+/**
+ * @ingroup glibmmValue
+ */
+class ValueBase_Variant : public ValueBase
+{
+public:
+  static GType value_type() G_GNUC_CONST;
+
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
+  GParamSpec* create_param_spec(const Glib::ustring& name, const Glib::ustring& nick,
+                                const Glib::ustring& blurb, Glib::ParamFlags flags) const;
+#endif
+
+protected:
+  void set_variant(GVariant* data);
+  GVariant* get_variant() const; // doesn't copy, may return nullptr
+};
+
+
 } // namespace Glib
 
-/* Include generic Glib::Value<> template, before any specializations:
+/* Include primary Glib::Value<> template, before any specializations:
  */
 #define _GLIBMM_VALUE_H_INCLUDE_VALUE_CUSTOM_H
 #include <glibmm/value_custom.h>
@@ -213,6 +233,7 @@ namespace Glib
 template <class T>
 class Value_Boxed : public ValueBase_Boxed
 {
+// Used by _CLASS_BOXEDTYPE and _CLASS_BOXEDTYPE_STATIC
 public:
   using CppType = T;
   using CType = typename T::BaseObjectType*;
@@ -223,6 +244,26 @@ public:
   CppType get() const { return CppType(static_cast<CType>(get_boxed())); }
 };
 
+/**
+ * @ingroup glibmmValue
+ */
+template <class T>
+class Value_RefPtrBoxed : public ValueBase_Boxed
+{
+// Used by _CLASS_OPAQUE_REFCOUNTED with _IS_REFCOUNTED_BOXEDTYPE
+public:
+  using CppType = Glib::RefPtr<T>;
+
+  static GType value_type() { return T::get_type(); }
+
+  // Equivalent to set_boxed(Glib::unwrap(data)) without including wrap.h.
+  void set(const CppType& data) { set_boxed(data ? data->gobj() : nullptr); }
+
+  // get() is defined in the Value<> specializations. It requires the declaration
+  // of Glib::wrap(T::BaseObjectType*, bool) to be visible.
+  // CppType get() const { return Glib::wrap(static_cast<typename T::BaseObjectType*>(get_boxed()), true); }
+};
+
 // More spec-compliant compilers (such as Tru64) need this to be near Glib::Object instead.
 #ifdef GLIBMM_CAN_USE_DYNAMIC_CAST_IN_UNUSED_TEMPLATE_WITHOUT_DEFINITION
 
@@ -301,6 +342,36 @@ public:
   Glib::ustring get() const { return get_cstring(); }
 };
 
+/** Specialization for vectors of strings.
+ * @ingroup glibmmValue
+ */
+template <>
+class Value<std::vector<std::string>> : public ValueBase_Boxed
+{
+public:
+  using CppType = std::vector<std::string>;
+
+  static GType value_type();
+
+  void set(const CppType& data);
+  CppType get() const;
+};
+
+/** Specialization for vectors of UTF-8 strings.
+ * @ingroup glibmmValue
+ */
+template <>
+class Value<std::vector<Glib::ustring>> : public ValueBase_Boxed
+{
+public:
+  using CppType = std::vector<Glib::ustring>;
+
+  static GType value_type();
+
+  void set(const CppType& data);
+  CppType get() const;
+};
+
 /** Base class of Glib::Value<T> specializations for enum types.
  * @ingroup glibmmValue
  */
